"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outPutFinancingList = exports.financingList = exports.getFuHuaQiEnterpriseForSelect = exports.deleteEnterpriseFinancingByUscc = exports.getEnterpriseFinancingByUscc = exports.updateFinancingInfo = exports.createFinancingInfo = void 0;
/**
 * 企业融资相关逻辑
 * 作者: 李欣鸣
 * 包括新融资信息的增删改查
 *
 */
const checkParamConfig_1 = require("../../config/checkParamConfig");
const errorEnum_1 = require("../../config/errorEnum");
const ojbectResultKeyConfig_1 = require("../../config/ojbectResultKeyConfig");
const financing_1 = require("../../data/enterprise/financing");
const ojbectResultKeyConfig_2 = require("../../config/ojbectResultKeyConfig");
const bizError_1 = require("../../util/bizError");
const tools_1 = require("../../util/tools");
const enterprise_1 = require("../../data/enterprise/enterprise");
const fuhuaqi_1 = require("../../data/fuHuaQi/fuhuaqi");
const moment = require("moment");
const enum_1 = require("../../config/enum");
/**
 * 添加企业融资信息
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param param 表单配置
 * @returns {isSuccess:true/false}
 */
async function createFinancingInfo(uscc, param) {
    tools_1.checkParamater("录入企业融资信息", checkParamConfig_1.FinancingParamConfig, param, ["fuHuaQiInvestment", "fuHuaQiInvestmentAmount", "fuHuaQiInvestmentStyle"]);
    if (param.fuHuaQiInvestment) {
        let subCheckName = "录入企业融资信息_孵化器是否参与";
        let subCheckData = {
            fuHuaQiInvestmentAmount: param.fuHuaQiInvestmentAmount,
            fuHuaQiInvestmentStyle: param.fuHuaQiInvestmentStyle,
        };
        tools_1.checkParamater(subCheckName, { fuHuaQiInvestmentAmount: "Number", fuHuaQiInvestmentStyle: "Number" }, subCheckData);
    }
    else {
        param.fuHuaQiInvestmentAmount = 0;
        param.fuHuaQiInvestmentStyle = 0;
    }
    /**校验企业是否存在 */
    let enterpriseInfo = await enterprise_1.findEnterpriseInfoByName(param.name);
    if (!enterpriseInfo)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该企业不存在, uscc, param.name);
    param.uscc = enterpriseInfo.uscc; //前端无需传入企业的uscc  库中需要企业的uscc
    const TaskId = tools_1.getTaskId(uscc);
    /**一个企业一个月只能填报一次融资信息 */
    let dataBaseInfo = await financing_1.findFinancingInfoByTaskIdAndSucc(TaskId, param.uscc);
    if (dataBaseInfo && dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该企业当月数据已存在, `${param.uscc}的融资信息已经存在`);
    await financing_1.createFinancing(uscc, TaskId, enterpriseInfo.uscc, enterpriseInfo.logonTime, param);
    return { isSuccess: true };
}
exports.createFinancingInfo = createFinancingInfo;
/**
 * 更新企业融资信息
 * 小程序端
 * 只能更新本月未提交的并且已经创建的企业融资信息
 * @param uscc 孵化器统一信用代码
 * @param param 表单配置
 * @returns {isSuccess:true/false}
 */
async function updateFinancingInfo(uscc, param) {
    tools_1.checkParamater("更新融资企业信息", checkParamConfig_1.FinancingParamUpdateConfig, param, ["fuHuaQiInvestmentAmount", "fuHuaQiInvestmentStyle"]);
    if (param.fuHuaQiInvestment) {
        let subCheckName = "录入企业融资信息_孵化器是否参与";
        let subCheckData = {
            fuHuaQiInvestmentAmount: param.fuHuaQiInvestmentAmount,
            fuHuaQiInvestmentStyle: param.fuHuaQiInvestmentStyle,
        };
        tools_1.checkParamater(subCheckName, { fuHuaQiInvestmentAmount: "String", fuHuaQiInvestmentStyle: "String" }, subCheckData);
    }
    else {
        param.fuHuaQiInvestmentAmount = 0;
        param.fuHuaQiInvestmentStyle = 0;
    }
    const TaskId = tools_1.getTaskId(uscc);
    let dataBaseInfo = await financing_1.findFinancingInfoByTaskIdAndSucc(TaskId, param.uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${TaskId}的任务`);
    let changeList = tools_1.checkChange(param, dataBaseInfo);
    if (!changeList.length)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.数据无更新, `${param.uscc}数据无更新`);
    changeList.forEach(key => {
        dataBaseInfo[key] = param[key];
    });
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.updateFinancingInfo = updateFinancingInfo;
/**
 * 查询本月提交的企业融资信息
 * 小程序端
 * @param fuHuaQiUscc 孵化器统一信用代码
 * @param uscc 企业统一信用代码
 * @returns {data:{}}  表单
 */
async function getEnterpriseFinancingByUscc(fuHuaQiUscc, uscc) {
    const TaskId = tools_1.getTaskId(fuHuaQiUscc);
    let dataBaseInfo = await financing_1.findFinancingInfoByTaskIdAndSucc(TaskId, uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${uscc}这个企业的本次融资数据`);
    let data = tools_1.extractData(ojbectResultKeyConfig_1.EnterpriseFinancingInfoConfig, dataBaseInfo, false);
    return { data };
}
exports.getEnterpriseFinancingByUscc = getEnterpriseFinancingByUscc;
/**
 * 根据企业id删除草稿企业
 * 小程序端
 * @param fuHuaQiUscc 孵化器统一信用代码
 * @param uscc 企业统一信用代码
 * @returns {isSuccess:true/false}
 */
async function deleteEnterpriseFinancingByUscc(fuHuaQiUscc, uscc) {
    const TaskId = tools_1.getTaskId(fuHuaQiUscc);
    let dataBaseInfo = await financing_1.findFinancingInfoByTaskIdAndSucc(TaskId, uscc);
    if (!dataBaseInfo || !dataBaseInfo.uscc)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `库中不存在${uscc}这个企业`);
    if (dataBaseInfo.draftLock)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.已入库的数据不能删除, uscc);
    await financing_1.deleteEnterpriseFinancing(uscc, TaskId);
    return { isSuccess: true };
}
exports.deleteEnterpriseFinancingByUscc = deleteEnterpriseFinancingByUscc;
/**
 * 获取本孵化器下的所有企业信息
 * 小程序端  用于下拉框使用
 * @param uscc 孵化器统一信用代码
 * @returns []  name:企业名称, logonAdd:注册地址, operatingAdd:经营地址
 */
async function getFuHuaQiEnterpriseForSelect(uscc) {
    let enterpriseList = await enterprise_1.findEnterpriseListByFuHuaQiUsccName(uscc);
    let dataList = [];
    enterpriseList.forEach(info => {
        dataList.push({
            name: info.name,
            logonAdd: info.logonAdd,
            operatingAdd: info.operatingAdd
        });
    });
    return dataList;
}
exports.getFuHuaQiEnterpriseForSelect = getFuHuaQiEnterpriseForSelect;
/**
 * 融资企业信息列表
 * 管理后台端
 * @param monthData 数据月份 目前数据库没有该字段
 * @param fuHuaQiName 所属孵化器
 * @param industry 行业领域
 * @param fuHuaQiInvestment 孵化器是否参与投资
 * @param page 页数
 * @returns
 */
async function financingList(monthData, fuHuaQiName, industry, fuHuaQiInvestment, page) {
    let fuHuaQiUscc = "";
    if (fuHuaQiName.length > 0) {
        let fuHuaQiInfo = await fuhuaqi_1.findFuHuaQiByName(fuHuaQiName);
        if (fuHuaQiInfo)
            fuHuaQiUscc = fuHuaQiInfo.uscc;
    }
    let selectParam = {};
    if (monthData.length > 0) {
        let startT = moment(monthData).startOf('month').valueOf();
        let endT = moment(monthData).endOf('month').valueOf();
        selectParam.createTime = { '$gt': startT, '$lt': endT };
    }
    if (industry.length > 0)
        selectParam.industry = industry;
    if (fuHuaQiUscc.length > 0)
        selectParam.fuHuaQiUscc = fuHuaQiUscc;
    if (fuHuaQiInvestment == 2 || fuHuaQiInvestment == 3) {
        selectParam.fuHuaQiInvestment = fuHuaQiInvestment == 2 ? true : false;
    }
    let dataBaseList = await financing_1.findFinancingListToPage(selectParam, (page - 1) * 10);
    let count = await financing_1.findFinancingCount(selectParam);
    let usccMap = await fuhuaqi_1.findAllFuHuaQiOperationNameMap();
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools_1.extractData(ojbectResultKeyConfig_2.FinancingListConfig, info, true);
        changeData.fuhuaqiUscc = usccMap[changeData.fuhuaqiUscc] || "";
        changeData.industry = tools_1.changeEnumValue(enum_1.INDUSTRY, changeData.industry);
        dataList.push(changeData);
    });
    return { count, dataList };
}
exports.financingList = financingList;
/**
 * 导出融资企业信息列表
 * 管理后台端
 * @param monthData 数据月份 目前数据库没有该字段
 * @param fuHuaQiName 所属孵化器
 * @param industry 行业领域
 * @param fuHuaQiInvestment 孵化器是否参与投资
 * @param page 页数
 * @returns
 */
async function outPutFinancingList(monthData, fuHuaQiName, industry, fuHuaQiInvestment, type) {
    let selectParam = {};
    if (type == enum_1.OUTPUTTYPE.当前数据) {
        let fuHuaQiUscc = "";
        if (fuHuaQiName.length > 0) {
            let fuHuaQiInfo = await fuhuaqi_1.findFuHuaQiByName(fuHuaQiName);
            if (fuHuaQiInfo)
                fuHuaQiUscc = fuHuaQiInfo.uscc;
        }
        if (monthData.length > 0) {
            let startT = moment(monthData).startOf('month').valueOf();
            let endT = moment(monthData).endOf('month').valueOf();
            selectParam.createTime = { '$gt': startT, '$lt': endT };
        }
        if (industry.length > 0)
            selectParam.industry = industry;
        if (fuHuaQiUscc.length > 0)
            selectParam.fuHuaQiUscc = fuHuaQiUscc;
        if (fuHuaQiInvestment == 2 || fuHuaQiInvestment == 3) {
            selectParam.fuHuaQiInvestment = fuHuaQiInvestment == 2 ? true : false;
        }
    }
    let dataBaseList = await financing_1.findFinancingList(selectParam);
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools_1.extractData(ojbectResultKeyConfig_2.FinancingListConfig, info, true);
        dataList.push(changeData);
    });
    return dataList;
}
exports.outPutFinancingList = outPutFinancingList;
//# sourceMappingURL=financing.js.map