"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outPutFuHuaQiBaseData = exports.fuHuaQiBaseList = exports.updateFuHuaQiBaseData = exports.selectFuHuaQiBaseData = exports.homeData = void 0;
/**
 * 孵化器基础数据相关逻辑
 * 作者: 李某
 * 孵化器相关逻辑 包括孵化器的增删改查
 *
 */
const checkParamConfig_1 = require("../../config/checkParamConfig");
const enterprise_1 = require("../../data/enterprise/enterprise");
const fuhuaqi_1 = require("../../data/fuHuaQi/fuhuaqi");
const tools = require("../../util/tools");
const ojbectResultKeyConfig_1 = require("../../config/ojbectResultKeyConfig");
const enum_1 = require("../../config/enum");
const tools_1 = require("../../util/tools");
const bizError_1 = require("../../util/bizError");
const errorEnum_1 = require("../../config/errorEnum");
/**
 * 主界面基础数据
 * 小程序端  首页的基础数据
 * 评分数据还没有
 * @param uscc 孵化器统一信用代码
 * @returns {} "incubatedAcreage", "acreageTotal", "acreagePersonalUse", "name", "lv", "institutionalNature"
 */
async function homeData(uscc) {
    let dataBaseInfo = await fuhuaqi_1.findFuHuaQiByUSCC(uscc);
    let data = tools_1.extractData(ojbectResultKeyConfig_1.FuHuaQiHomeDataConfig, dataBaseInfo, false);
    data.enterpriseCount = await enterprise_1.findEnterpriseCountByFuHuaQiUscc(uscc);
    data.lv = tools.changeEnumValue(enum_1.FUHUAQILV, dataBaseInfo.lv);
    data.institutionalNature = tools.changeEnumValue(enum_1.INSTITUTIONALNATURE, dataBaseInfo.institutionalNature);
    return data;
}
exports.homeData = homeData;
/**
 * 孵化器详细数据
 * 小程序端  点击我的数据之后拉取的详细数据
 * @param uscc 孵化器统一信用代码
 * @returns data 基础数据字段
 */
async function selectFuHuaQiBaseData(uscc) {
    let dataBaseInfo = await fuhuaqi_1.findFuHuaQiByUSCC(uscc);
    let enterpriseTotal = await enterprise_1.findEnterpriseCountByFuHuaQiUscc(uscc); //企业总数
    let data = tools_1.extractData(ojbectResultKeyConfig_1.FuHuaQiBaseDataConfig, dataBaseInfo, false);
    data.enterpriseTotal = enterpriseTotal;
    data.numOfEntities = enterpriseTotal - dataBaseInfo.virtualEnterpriseNum; //企业总数 - 虚拟企业数量
    return data;
}
exports.selectFuHuaQiBaseData = selectFuHuaQiBaseData;
/**
 * 更新孵化器基础数据
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param param 表单内容
 * @returns {isSuccess:true/false};
 */
async function updateFuHuaQiBaseData(uscc, param) {
    let skipKeyList = [
        "name", "virtualEnterpriseNum", "logonTime", "incubatedAcreage", "acreageTotal", "acreagePersonalUse", "lv", "identificationTime",
        "industry", "institutionalNature", "liaison", "liaisonPhone", "personInCharge", "personInChargePhone", "hatchingGround"
    ];
    tools.checkParamater("更新孵化器基础数据", checkParamConfig_1.BaseParamUpdateConfig, param, skipKeyList);
    let baseDataInfo = await fuhuaqi_1.findFuHuaQiByUSCC(uscc);
    for (let key in param) {
        if (key == "hatchingGround") {
            param[key].forEach(info => {
                let { personInChargeAdd, siteAcreage, leasePrice } = info;
                if (typeof personInChargeAdd != 'string')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `personInChargeAdd应是string型 而不是${typeof personInChargeAdd}`);
                if (typeof siteAcreage != 'number')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `siteAcreage应是number型 而不是${typeof personInChargeAdd}`);
                if (typeof leasePrice != 'number')
                    throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, `leasePrice应是number型 而不是${typeof personInChargeAdd}`);
            });
        }
    }
    //todo  这里有个bug
    let changeList = tools.checkChange(param, baseDataInfo);
    for (let i = 0; i < changeList.length; i++) {
        let key = changeList[i];
        baseDataInfo[key] = param[key];
    }
    await baseDataInfo.save();
    return { isSuccess: true };
}
exports.updateFuHuaQiBaseData = updateFuHuaQiBaseData;
/**
 * 获取孵化器基本信息列表
 * 管理后台端
 * @param lv 孵化器等级
 * @param institutionalNature 机构性质
 * @param industry 领域
 * @param page 页数
 * @returns
 */
async function fuHuaQiBaseList(lv, institutionalNature, industry, page) {
    let selectParam = {};
    if (lv)
        selectParam.lv = lv;
    if (institutionalNature)
        selectParam.institutionalNature = institutionalNature;
    if (industry)
        selectParam.industry = industry;
    let enterpriseMap = await enterprise_1.groupFindEnterprise(); //企业总数
    let dataBaseList = await fuhuaqi_1.findFuHuaQiListByPage(selectParam, (page - 1) * 10);
    let count = await fuhuaqi_1.findFuHuaQiCount(selectParam);
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools.extractData(ojbectResultKeyConfig_1.FuHuaQiBaseListConfig, info, true);
        // let hatchingGround = info.hatchingGround;
        // hatchingGround.forEach (info => {
        //     let {personInChargeAdd, siteAcreage, leasePrice} = info;
        //     changeData.personInChargeAdd = personInChargeAdd;
        //     changeData.siteAcreage = siteAcreage;
        //     changeData.leasePrice = leasePrice;
        // })
        let enterpriseTotal = enterpriseMap[info.uscc] || 0;
        let numOfEntities = enterpriseTotal - (info.virtualEnterpriseNum || 0);
        numOfEntities = numOfEntities < 0 ? 0 : numOfEntities;
        changeData.enterpriseTotal = enterpriseTotal;
        changeData.numOfEntities = numOfEntities;
        changeData.lv = tools.changeEnumValue(enum_1.FUHUAQILV, changeData.lv);
        changeData.industry = tools.changeEnumValue(enum_1.FUHUAINDUSTRY, changeData.industry);
        changeData.institutionalNature = tools.changeEnumValue(enum_1.INSTITUTIONALNATURE, changeData.institutionalNature);
        dataList.push(changeData);
    });
    return { count, dataList };
}
exports.fuHuaQiBaseList = fuHuaQiBaseList;
/**
 * 导出符合条件的孵化器基本信息数据
 * @param lv
 * @param institutionalNature
 * @param industry
 * @returns
 */
async function outPutFuHuaQiBaseData(lv, institutionalNature, industry, type) {
    let selectParam = {};
    if (type == enum_1.OUTPUTTYPE.当前数据) {
        if (lv)
            selectParam.lv = lv;
        if (institutionalNature)
            selectParam.institutionalNature = institutionalNature;
        if (industry)
            selectParam.industry = industry;
    }
    let enterpriseMap = await enterprise_1.groupFindEnterprise(); //企业总数
    let dataBaseList = await fuhuaqi_1.findFuHuaQiList(selectParam);
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools.extractData(ojbectResultKeyConfig_1.FuHuaQiBaseListConfig, info, true);
        let enterpriseTotal = enterpriseMap[info.uscc] || 0;
        let numOfEntities = enterpriseTotal - (info.virtualEnterpriseNum || 0);
        numOfEntities = numOfEntities < 0 ? 0 : numOfEntities;
        changeData.enterpriseTotal = enterpriseTotal;
        changeData.numOfEntities = numOfEntities;
        changeData.lv = tools.changeEnumValue(enum_1.FUHUAQILV, changeData.lv);
        changeData.industry = tools.changeEnumValue(enum_1.FUHUAINDUSTRY, changeData.industry);
        changeData.institutionalNature = tools.changeEnumValue(enum_1.INSTITUTIONALNATURE, changeData.institutionalNature);
        dataList.push(changeData);
    });
    return dataList;
}
exports.outPutFuHuaQiBaseData = outPutFuHuaQiBaseData;
//# sourceMappingURL=base.js.map