"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outPutMonthTableList = exports.monthTableList = exports.getMonthByUscc = exports.deleteReport = exports.updateReport = exports.createReport = void 0;
/**
 * 月度表单逻辑层
 * 作者: 陈金晶
 * 月度表单相关逻辑 包括孵化器月度填报的增删改查
 * 月度表单在孵化器任务生成时 就会在库里存在数据
 */
const errorEnum_1 = require("../../config/errorEnum");
const bizError_1 = require("../../util/bizError");
const monthData = require("../../data/fuHuaQi/monthTable");
const tools_1 = require("../../util/tools");
const fuhuaqi_1 = require("../../data/fuHuaQi/fuhuaqi");
const ojbectResultKeyConfig_1 = require("../../config/ojbectResultKeyConfig");
const enum_1 = require("../../config/enum");
/**
 * 新添加孵化器月度填报
 * 小程序端
 * 逻辑是 将填报编辑状态修改
 * @param uscc 孵化器的统一信用代码
 * @param occupancyRate 本月出租率
 * @returns {isSuccess:true/false}
 */
async function createReport(uscc, occupancyRate) {
    const TaskId = tools_1.getTaskId(uscc);
    let dataBaseInfo = await monthData.findMonthTableByTaskId(TaskId);
    if (dataBaseInfo.isUpdate)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该孵化器月度填报已存在, `${uscc}重复提交了月度填报值为${occupancyRate}`);
    dataBaseInfo.isUpdate = true;
    dataBaseInfo.occupancyRate = occupancyRate;
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.createReport = createReport;
/**
 * 修改孵化器月度报表
 * 小程序端
 * @param uscc 孵化器的统一信用代码
 * @param occupancyRate 本月出租率
 * @returns {isSuccess:true/false}
 */
async function updateReport(uscc, occupancyRate) {
    const TaskId = tools_1.getTaskId(uscc);
    let dataBaseInfo = await monthData.findMonthTableByTaskId(TaskId);
    if (!dataBaseInfo || !dataBaseInfo.taskId)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `未找到${uscc}的月度报表`);
    dataBaseInfo.occupancyRate = occupancyRate;
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.updateReport = updateReport;
/**
 * 删除孵化器月度报表
 * 小程序端
 * @param uscc 孵化器的统一信用代码
 * @returns  {isSuccess:true/false}
 */
async function deleteReport(uscc) {
    const TaskId = tools_1.getTaskId(uscc);
    let dataBaseInfo = await monthData.findMonthTableByTaskId(TaskId);
    if (!dataBaseInfo.isUpdate)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `未找到${uscc}的月度报表`);
    dataBaseInfo.isUpdate = false; //修改编辑状态
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.deleteReport = deleteReport;
/**
 * 根据uscc查询月度报表
 * 小程序端  回显
 * @param uscc 企业统一信用代码
 * @returns {occupancyRate:0} occupancyRate 本月出租率
 */
async function getMonthByUscc(uscc) {
    const TaskId = tools_1.getTaskId(uscc);
    let dataBaseInfo = await monthData.findMonthTableByTaskId(TaskId);
    if (!dataBaseInfo.isUpdate)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据, `未找到${uscc}的月度报表`);
    let data = tools_1.extractData(ojbectResultKeyConfig_1.MonthConfig, dataBaseInfo, false);
    return { data };
}
exports.getMonthByUscc = getMonthByUscc;
/**
 * 月度出租率数据列表
 * 管理后台端
 * @param state 填报状态
 * @param year 数据年份
 * @param month 数据月份
 * @param page 页面
 */
async function monthTableList(state, year, month, page) {
    let selectParam = {};
    // if (state) selectParam.state = state;
    if (state == 2 || state == 3) {
        selectParam.draftLock = state == 2 ? true : false;
    }
    if (year)
        selectParam.year = year;
    if (month)
        selectParam.month = month;
    let dataBaseList = await monthData.findMonthTableListToPage(selectParam, (page - 1) * 10);
    let count = await monthData.findMonthTableListCount(selectParam);
    let operationNameMap = await fuhuaqi_1.findAllFuHuaQiOperationNameMap();
    let dataList = [];
    dataBaseList.forEach(info => {
        let onceInfo = {
            operationName: operationNameMap[info.fuHuaQiUscc],
            state: info.draftLock == false ? '未填报' : '已填报',
            time: `${info.year}年${info.month}月`,
            occupancyRate: info.occupancyRate || '-'
        };
        dataList.push(onceInfo);
    });
    return { count, dataList };
}
exports.monthTableList = monthTableList;
/**
 * 导出月度出租率数据列表
 * 管理后台端
 * @param state 填报状态
 * @param year 数据年份
 * @param month 数据月份
 * @param page 页面
 */
async function outPutMonthTableList(state, year, month, type) {
    let selectParam = {};
    // if (state) selectParam.state = state;
    if (type == enum_1.OUTPUTTYPE.当前数据) {
        if (state == 2 || state == 3) {
            selectParam.draftLock = state == 2 ? true : false;
        }
        if (year)
            selectParam.year = year;
        if (month)
            selectParam.month = month;
    }
    let dataBaseList = await monthData.findMonthTableList(selectParam);
    let operationNameMap = await fuhuaqi_1.findAllFuHuaQiOperationNameMap();
    let dataList = [];
    dataBaseList.forEach(info => {
        let onceInfo = {
            operationName: operationNameMap[info.fuHuaQiUscc],
            state: info.draftLock == false ? '未填报' : '已填报',
            time: `${info.year}年${info.month}月`,
            occupancyRate: info.occupancyRate || '-'
        };
        dataList.push(onceInfo);
    });
    return dataList;
}
exports.outPutMonthTableList = outPutMonthTableList;
//# sourceMappingURL=month.js.map