"use strict";
/**
 * 孵化器任务相关逻辑
 * 作者: 李某
 * 任务相关逻辑 包括任务的增删改查 管理后台的任务列表逻辑
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.provideTask = exports.checkTask = exports.fuHuaQiTaskList = void 0;
const moment = require("moment");
const enum_1 = require("../../config/enum");
const errorEnum_1 = require("../../config/errorEnum");
const enterprise_1 = require("../../data/enterprise/enterprise");
const financing_1 = require("../../data/enterprise/financing");
const fuhuaqi_1 = require("../../data/fuHuaQi/fuhuaqi");
const monthTable_1 = require("../../data/fuHuaQi/monthTable");
const task_1 = require("../../data/fuHuaQi/task");
const bizError_1 = require("../../util/bizError");
const log_1 = require("../../util/log");
const tools_1 = require("../../util/tools");
/**
 * 获取孵化器的任务列表
 * 小程序端
 * @param uscc 孵化器统一信用
 * @returns [{type:1, title:'', enterpriseList:[] }]
 */
async function fuHuaQiTaskList(uscc) {
    let result = [];
    const TaskId = tools_1.getTaskId(uscc);
    let taskMap = await task_1.findFuHuaQiTaskByTaskId(TaskId);
    // let taskTypeMapConf = {};
    for (let key in enum_1.TASKTYPEENUM) {
        let k = key;
        if (isNaN(k)) {
            const Value = k;
            const KeyStr = enum_1.TASKTYPEENUM[key];
            let keyNumber = parseInt(KeyStr);
            let onceObj = { key: keyNumber, title: Value, enterpriseList: [] };
            let onceTaskInfo = taskMap[KeyStr];
            if (!onceTaskInfo.isSubmit) { //没有提交任务
                let dataList = [];
                switch (keyNumber) {
                    case enum_1.TASKTYPEENUM.孵化器月度填报:
                        dataList = await monthTable_1.findmonthTableListByTaskId(TaskId);
                        break;
                    case enum_1.TASKTYPEENUM.新注册或迁入企业登记:
                        dataList = await enterprise_1.findEnterpriseListByTaskId(TaskId);
                        break;
                    case enum_1.TASKTYPEENUM.融资企业填报:
                        dataList = await financing_1.findFinancingListByTaskId(TaskId);
                        break;
                }
                dataList.forEach(info => {
                    let addInfo = { name: info.name, id: info.uscc, isCreate: info.isCreate || false };
                    onceObj.enterpriseList.push(addInfo);
                });
                result.push(onceObj);
            }
        }
    }
    return { taskList: result };
}
exports.fuHuaQiTaskList = fuHuaQiTaskList;
/**
 * 提交任务
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param taskType 任务类型
 * @returns {isSuccess:true/false}
 */
async function checkTask(uscc, taskType) {
    const TaskId = tools_1.getTaskId(uscc);
    let taskInfo = await task_1.findEnterpriseByTaskIdAndType(TaskId, taskType);
    if (!taskInfo)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.任务不存在, uscc, TaskId);
    if (taskInfo.isSubmit)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.不能重复提交任务, uscc, taskType);
    switch (taskType) {
        case enum_1.TASKTYPEENUM.孵化器月度填报:
            let monthTableInfo = await monthTable_1.findMonthTableByTaskId(TaskId);
            if (!monthTableInfo.isUpdate)
                throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该报表需要填写本月内容后提交, uscc, taskType);
            if (monthTableInfo.draftLock)
                throw new bizError_1.BizError(errorEnum_1.ERRORENUM.不能重复提交任务, uscc, taskType, '月度表lock = true');
            monthTableInfo.draftLock = true;
            await monthTableInfo.save();
            break;
        case enum_1.TASKTYPEENUM.新注册或迁入企业登记:
            await enterprise_1.updateEnterpriseDraftLock(TaskId);
            break;
        case enum_1.TASKTYPEENUM.融资企业填报:
            await financing_1.updateFinancingDraftLock(TaskId);
            break;
    }
    //添加一条任务
    taskInfo.isSubmit = true;
    taskInfo.submitTime = new Date().valueOf();
    await taskInfo.save();
    return { isSuccess: true };
}
exports.checkTask = checkTask;
/**
 * 发放任务
 * 系统自发
 * 需求说明:
 * 每月1日0时0分，将任务下发至孵化器表中未被禁用的孵化器中
 *
 */
async function provideTask() {
    const TimeKey = tools_1.getTimeKey();
    let taskCount = await task_1.findTaskCountByKey(TimeKey);
    if (taskCount) { } //todo 重复创建了任务
    let fuHuaQiList = await fuhuaqi_1.findAllFuHuaQi();
    const Month = new Date().getMonth() + 1;
    let addList = []; //任务列表
    let monthList = []; //月度填报列表
    const MonthNumber = moment().subtract(1, 'months').month() + 1;
    const YearNumber = new Date().getFullYear();
    const MonthTableName = `${MonthNumber}月孵化器月度填报`;
    fuHuaQiList.forEach(info => {
        let { uscc } = info;
        let taskId = tools_1.getTaskId(uscc);
        addList.push({
            key: TimeKey,
            type: enum_1.TASKTYPEENUM.孵化器月度填报,
            taskId,
            fuHuaQiUscc: uscc,
            isSubmit: false
        }, {
            key: TimeKey,
            type: enum_1.TASKTYPEENUM.新注册或迁入企业登记,
            taskId,
            fuHuaQiUscc: uscc,
            isSubmit: false
        }, {
            key: TimeKey,
            type: enum_1.TASKTYPEENUM.融资企业填报,
            taskId,
            fuHuaQiUscc: uscc,
            isSubmit: false
        });
        monthList.push({
            taskId,
            name: MonthTableName,
            fuHuaQiUscc: uscc,
            month: MonthNumber,
            year: YearNumber,
            draftLock: false
        });
    });
    try {
        await task_1.createTaskToList(addList);
        /**添加月度填报表 */
        await monthTable_1.createMonthTableToList(monthList);
        log_1.logHandle(`添加了${addList.length}`);
    }
    catch (err) {
        //todo添加异常了
    }
}
exports.provideTask = provideTask;
//# sourceMappingURL=task.js.map