"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addUser = exports.updateState = exports.fuHuaQiUserList = exports.logout = exports.changePassword = exports.firstLoginChangePwd = exports.login = void 0;
/**
 * 孵化器用户逻辑层
 * 作者: 陈金晶
 * 主要包括有 孵化器账号的登录
 * 预留好  重置密码  退出登录 接口
 */
const checkParamConfig_1 = require("../../config/checkParamConfig");
const errorEnum_1 = require("../../config/errorEnum");
const ojbectResultKeyConfig_1 = require("../../config/ojbectResultKeyConfig");
const fuhuaqiData = require("../../data/fuHuaQi/fuhuaqi");
const bizError_1 = require("../../util/bizError");
const tools_1 = require("../../util/tools");
/**
 * 小程序的孵化器登录
 * 小程序端
 * @param uscc 信用代码
 * @param pwd 密码
 * @returns fuhuaqiUserInfo:{uscc, name} 登录后的信息
 */
async function login(uscc, pwd) {
    let fuhuaqiInfo = await fuhuaqiData.findFuHuaQiByUSCC(uscc);
    if (!fuhuaqiInfo)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.账号不存在);
    let checkPwd = tools_1.getPwdMd5(fuhuaqiInfo.uscc, pwd);
    if (fuhuaqiInfo.pwd != checkPwd)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.密码错误);
    const Token = tools_1.getToken(uscc);
    let fuhuaqiUserInfo = {
        uscc: fuhuaqiInfo.uscc,
        // name: fuhuaqiInfo.name,
        firstLogin: !fuhuaqiInfo.firstLoginIsChangePwd,
        token: Token
    };
    fuhuaqiInfo.token = Token;
    fuhuaqiInfo.tokenMs = new Date().valueOf();
    await fuhuaqiInfo.save();
    return fuhuaqiUserInfo;
}
exports.login = login;
/**
 * 首次登录修改密码
 * 小程序端
 * @param uscc 孵化器统一信用代码
 * @param pwd 新密码
 * @param confirmPwd 确认密码
 * @returns
 */
async function firstLoginChangePwd(uscc, pwd, confirmPwd) {
    let dataBaseInfo = await fuhuaqiData.findFuHuaQiByUSCC(uscc);
    if (dataBaseInfo.firstLoginIsChangePwd)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.不能重复修改密码, `重复调用了首次登录之后的修改密码接口${uscc}`);
    //todo 校验密码
    dataBaseInfo.pwd = tools_1.getPwdMd5(uscc, pwd);
    dataBaseInfo.firstLoginIsChangePwd = true;
    await dataBaseInfo.save();
    return { isSuccess: true };
}
exports.firstLoginChangePwd = firstLoginChangePwd;
/**
 * 重置密码
 * 小程序端
 * @param uscc 信用代码
 * @param pwd 原密码
 * @param newPwd 修改后的密码
 * @returns {isSuccess:true/false}
 */
async function changePassword(uscc, pwd, newPwd) {
    let reg = new RegExp("[`~!@#$^&*()=|{}':;',\\[\\].<>/?~！@#￥……&*（）——|{}【】‘；：”“'。，、？]");
    if (reg.test(newPwd)) {
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.密码不允许有特殊字符, uscc, pwd);
    }
    if (pwd.length > 24) {
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.密码长度不能超过24个字符, uscc, pwd);
    }
    let fuhuaqiInfo = await fuhuaqiData.findFuHuaQiByUSCC(uscc);
    if (!fuhuaqiInfo)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.未找到数据);
    let checkPwd = tools_1.getPwdMd5(fuhuaqiInfo.uscc, pwd);
    if (fuhuaqiInfo.pwd != checkPwd)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.密码错误);
    fuhuaqiInfo.pwd = tools_1.getPwdMd5(uscc, newPwd);
    await fuhuaqiInfo.save();
    return { isSuccess: true };
}
exports.changePassword = changePassword;
/**
 * 退出登录
 * 小程序端
 * @param uscc 信用代码
 * @returns {isSuccess:true/false}
 */
async function logout(uscc) {
    if (typeof uscc != "string")
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误, uscc);
    let fuhuaqiInfo = await fuhuaqiData.findFuHuaQiByUSCC(uscc);
    await fuhuaqiInfo.save();
    return { isSuccess: true };
}
exports.logout = logout;
/**
 * 孵化器账号信息列表
 * 管理后台使用
 * @param operationName 运营机构名称
 * @param page 页数
 * @returns
 */
async function fuHuaQiUserList(operationName, page) {
    let selectParam = {};
    if (operationName) {
        selectParam.operationName = { "$regex": `${operationName}` };
        ;
    }
    let enterpriseMap = await fuhuaqiData.groupFindFuHuaQi();
    let dataBaseList = await fuhuaqiData.findFuHuaQiUserList(selectParam, (page - 1) * 10);
    let count = await fuhuaqiData.findFuHuaQiUserCount(selectParam);
    let dataList = [];
    dataBaseList.forEach(info => {
        let changeData = tools_1.extractData(ojbectResultKeyConfig_1.FuHuaQiListConfig, info, true);
        const Count = enterpriseMap[info.uscc] || 0;
        dataList.push(changeData);
    });
    return { count, dataList };
}
exports.fuHuaQiUserList = fuHuaQiUserList;
/**
 * 修改账号状态
 * 管理后台端  禁用/启用
 * @param uscc 孵化器统一信用代码
 * @param userStatem 是否禁用  true=启用 false=禁用
 * @returns
 */
async function updateState(uscc, userState) {
    let fuhuaqiInfo = await fuhuaqiData.findFuHuaQiByUSCC(uscc);
    if (!fuhuaqiInfo)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.账号不存在);
    fuhuaqiInfo.userState = userState;
    await fuhuaqiInfo.save();
    return { isSuccess: true };
}
exports.updateState = updateState;
/**
 * 添加孵化器账号
 * 管理后台端
 * @param param 表单信息
 * @returns
 */
async function addUser(param) {
    tools_1.checkParamater("新增孵化器账号信息", checkParamConfig_1.FuHuaQiUserConfig, param); //校验表单参数
    let fuhuaqiInfo = await fuhuaqiData.findFuHuaQiByUSCC(param.uscc);
    if (fuhuaqiInfo)
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.该孵化器账号信息已存在, `${param.uscc}`);
    const Pwd = param.uscc.slice(param.uscc.length - 3);
    param.pwd = Pwd;
    await fuhuaqiData.createFuHuaQiUser(param);
    return { isSuccess: true };
}
exports.addUser = addUser;
//# sourceMappingURL=user.js.map