"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.carInfo = exports.mapData = exports.getCSFX = exports.getCSGK = exports.getYZY = void 0;
const moment = require("moment");
const out_1 = require("../../cal/out");
const privateTools_1 = require("../../cal/privateTools");
const serverConfig_1 = require("../../config/serverConfig");
const hardwareData_1 = require("../../data/interface/hardwareData");
// import { getCsgkData, getDetachmentRatio, getTestAnalysis, getTestTotalTime } from "../../data/interface/interfaceService";
const mapInterfaceData_1 = require("../../data/interface/mapInterfaceData");
const wsData_1 = require("../../data/interface/wsData");
const csfxData_1 = require("../../data/dataCenterInterface/csfxData");
const csgkData_1 = require("../../data/dataCenterInterface/csgkData");
const cronJob_1 = require("../../data/cronJob");
const bizError_1 = require("../../util/bizError");
const errorEnum_1 = require("../../config/errorEnum");
const control_1 = require("../control");
//云资源
async function getYZY(req, res) {
    let ret = {};
    let { 计算云资源, 使用率, 物理资源 } = await hardwareData_1.getHardware();
    ret["api1"] = out_1.getKeyValueNumberOutData("计算云资源", 计算云资源);
    ret["api2"] = out_1.getKeyValueNumberOutData("计算云资源使用率", 使用率);
    ret["api3"] = out_1.getKeyValueNumberOutData("物理资源", 物理资源);
    res.send(ret);
}
exports.getYZY = getYZY;
//测试概况
async function getCSGK(req, res) {
    let ret = {};
    let { cspzData, jcsjData } = await csgkData_1.getInterfaceData();
    let 基础数据Info = [];
    jcsjData.forEach((info, index) => {
        let { key, value } = info;
        let { dataNum, dataUnit } = privateTools_1.separateDataAndUint(value);
        基础数据Info.push({ key, value: dataNum, unit: dataUnit, icon: `http://${serverConfig_1.getImageIp()}:${serverConfig_1.systemConfig.port}/csgk/${index + 1}.png` });
    });
    ret["api1"] = ({ title: "基础数据", dataList: 基础数据Info });
    let 今日数据data = { "在线车辆数": `${wsData_1.getOnlieCarCount()}辆` };
    let { 今日数据, 今日测试, 今日功能测试 } = await csgkData_1.getJrsj();
    ret["api2"] = out_1.getKeyValueNumberOutData("今日数据", 今日数据data);
    ret["api3"] = out_1.getKeyValueNumberOutData("今日测试", 今日测试);
    ret["api4"] = out_1.getKeyValueNumberOutData("今日功能测试", 今日功能测试);
    ret["api5"] = out_1.getKeyValueNumberOutData("测试牌照分布", cspzData);
    let 路侧监控视频data = { "src": serverConfig_1.appConfig.surveillanceVideo, "type": 'application/x-mpegURL' };
    ret["api6"] = ({ title: "路侧监控视频", dataList: 路侧监控视频data });
    res.send(ret);
}
exports.getCSGK = getCSGK;
//测试分析
async function getCSFX(req, res) {
    let ret = {};
    let 企业测试自动驾驶比率Info = await csfxData_1.getQytlzdjs();
    ret["api5"] = out_1.getListOutData("企业脱离自动驾驶比率", 企业测试自动驾驶比率Info);
    let { 月度测试时长数据, 月度测试时长功能数据, 月度测试里程数据, 月度测试里程功能数据 } = await csfxData_1.getYdcs();
    let 月度测试里程分布data = { 测试: { unit: 'km', dataInfo: 月度测试里程数据 }, 功能测试: { unit: 'km', dataInfo: 月度测试里程功能数据 } };
    ret["api1"] = out_1.getChartOutData("月度测试里程分布", 月度测试里程分布data);
    let 月度测试时长分布data = { 测试: { unit: 'h', dataInfo: 月度测试时长数据 }, 功能测试: { unit: 'h', dataInfo: 月度测试时长功能数据 } };
    ret["api2"] = out_1.getChartOutData("月度测试时长分布", 月度测试时长分布data);
    let { 企业测试时长数据, 企业测试时长功能数据, 企业测试里程数据, 企业测试里程功能数据 } = await csfxData_1.getQycs();
    let 企业测试里程分布data = { 测试: { unit: 'km', dataInfo: 企业测试里程数据 }, 功能测试: { unit: 'km', dataInfo: 企业测试里程功能数据 } };
    ret["api3"] = out_1.getChartOutData("企业测试里程分布", 企业测试里程分布data);
    let 企业测试时长分布data = { 测试: { unit: 'h', dataInfo: 企业测试时长数据 }, 功能测试: { unit: 'h', dataInfo: 企业测试时长功能数据 } };
    ret["api4"] = out_1.getChartOutData("企业测试时长分布", 企业测试时长分布data);
    res.send(ret);
}
exports.getCSFX = getCSFX;
async function mapData(req, res) {
    //地图数据结构
    let ret = {};
    let mapInfoData = await mapInterfaceData_1.getMap();
    let { cameraData, lidarData, millimeterWaveRadarData, RSUData, SIBOXData } = mapInfoData;
    let { cameraCount, holographicIntersectionCount, laserRadarCount, mecCount, mmwCount, roadMileage, rsuCount, siboxCount, smartIntersectionCount } = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.roadConstructionInfo, {});
    let 基础数据data = {
        "摄像机": cameraCount,
        "激光雷达": laserRadarCount,
        "毫米波雷达": mmwCount,
        "RSU": rsuCount,
        "MEC": mecCount,
        "SiBox": siboxCount,
    };
    ret["base"] = out_1.getKeyValueNumberOutData("基础数据右", 基础数据data);
    let roadData = {
        "车路协同建设里程": roadMileage,
        "智慧路口数": smartIntersectionCount,
        "全息路口数": holographicIntersectionCount
    };
    ret["roadBase"] = out_1.getKeyValueNumberOutData("基础数据左", roadData);
    ret["map"] = [
        {
            name: "camera",
            value: cameraData
        },
        {
            name: "lidar",
            value: lidarData
        },
        // },
        // {
        //     name: "waveRadar",
        //     value: millimeterWaveRadarData
        // },
        {
            name: "RSU",
            value: RSUData
        },
        {
            name: "SIBOX",
            value: SIBOXData
        }
    ];
    ret["mapCenter"] = { lng: serverConfig_1.appConfig.lng, lat: serverConfig_1.appConfig.lat };
    ret["zoom"] = { key: "缩放比例", value: serverConfig_1.appConfig.zoom };
    res.send(ret);
}
exports.mapData = mapData;
//当前监控的sessionId
//小车详情
async function carInfo(req, res) {
    let { carId } = req.body;
    if (!carId) {
        throw new bizError_1.BizError(errorEnum_1.ERRORENUM.参数错误);
    }
    let carInfo = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.vehicleInfo, { vin: carId });
    //获取
    let ret = {};
    ret["info"] = {
        enterprise: carInfo.enterprise,
        validityBegin: carInfo.validityBegin,
        validityEnd: carInfo.validityEnd,
        vehicleNo: carInfo.vehicleNo,
        vin: carInfo.vin,
        vehicleType: carInfo.vehicleType,
        type: "自动驾驶",
        velocity: "45km/h"
    };
    let endTime = moment().format("YYYY-MM-DD hh:mm:ss");
    let startTime = moment().subtract(10, 'd').format("YYYY-MM-DD hh:mm:ss");
    let testData = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.testHistory, { vin: carId, startTime, endTime });
    let 测试里程 = [];
    let 功能测试里程 = [];
    testData.monthlyTestStatusList.forEach(info => {
        let { date, testStatistics } = info;
        let key = moment(date).format("YYYY.MM");
        let { autoDuration, autoMileage, duration, mileage } = testStatistics;
        测试里程.push({ key, value: mileage });
        功能测试里程.push({ key, value: autoMileage });
    });
    let 月度测试时长分布data = { 测试里程: { unit: 'h', dataInfo: 测试里程 }, 功能测试里程: { unit: 'h', dataInfo: 功能测试里程 } };
    ret["lcbhqs"] = out_1.getChartOutData("里程变化趋势", 月度测试时长分布data);
    //获取小车信息
    let alertEndTime = moment().format("YYYY-MM-DD hh:mm:ss");
    let alertStartTime = moment().subtract(1, 'd').format("YYYY-MM-DD hh:mm:ss");
    let alertData = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.vehicleAlert, {
        vin: carId,
        startTime: alertStartTime,
        endTime: alertEndTime
    });
    let 车辆违规列表 = [];
    alertData.list.forEach((item, index) => {
        if (index >= 10)
            return;
        let { alertDuration, alertType, positionTime, velocity } = item;
        let alertDurationStr = `${alertDuration}`;
        let alertTypeStr = alertType == 1 ? '违规开启自动驾驶模式' : "手动模式";
        车辆违规列表.push([positionTime, alertTypeStr, alertDurationStr, `${velocity}km/h`]);
    });
    ret["testInfo"] = {
        mileage: "422km",
        duration: "21h",
        allMileage: "1222km",
        allDuration: "5666h"
    };
    ret["clwgqk"] = {
        title: "车辆违规情况",
        dataList: 车辆违规列表
    };
    //测试车辆监控地址
    let testVideoData = await cronJob_1.getCarVideo(serverConfig_1.dataCenterInterfaceConfig.videoPlay, { vin: carId });
    //测试车辆监控图片封面
    let videoPictureData = await cronJob_1.getCarVideo(serverConfig_1.dataCenterInterfaceConfig.videoPicture, { vin: carId });
    let isNull = false;
    let 监控视频列表 = [];
    if (testVideoData && videoPictureData) {
        let map = {};
        videoPictureData.vehiclePhotoList.forEach(info => {
            let { photo, photoChannel } = info;
            map[photoChannel] = photo;
        });
        let { sessionId, rtmpAddresss } = testVideoData;
        rtmpAddresss.forEach(info => {
            let { channelNo, address } = info;
            console.log(address);
            监控视频列表.push({
                video: address,
                img: map[channelNo],
                type: 'application/x-mpegURL'
            });
        });
        control_1.updateSessionId(carId, sessionId);
    }
    else
        isNull = true;
    ret["csclsp"] = {
        title: "测试车辆视频",
        dataList: 监控视频列表,
        isNull
    };
    res.send(ret);
}
exports.carInfo = carInfo;
//# sourceMappingURL=data.js.map