"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getScatterFigureOutData = exports.getKeyValueNotNumberOutData = exports.getKeyValueNumberOutData = exports.getListOutData = exports.getChartOutData = exports.getStringOutData = void 0;
const privateTools_1 = require("./privateTools");
//标准化输出  这里的东西禁止 乱改以及临时更改
/**
 * getStringOutData  获取文字列表返回结果
 * @param title  数据标题
 * @param data 数据体 格式:["txt...", "str..."]
 * @returns {title, dataList:[string...]}
 */
function getStringOutData(title, data) {
    let dataList = [];
    data.forEach((str) => {
        dataList.push(str);
    });
    return { title, dataList };
}
exports.getStringOutData = getStringOutData;
/**
 * getChartData  获取图表返回结果
 * @param title 数据标题
 * @param data  数据体  格式：{"图表名称":{unit:"", dataInfo:[{key:"数据key", value:"数据值"}, {key:"数据key", value:"数据值"} ] } }
 * @param haveMoreY 是否有多个y轴  默认false
 * @returns {title:标题, dataList:[{unit:单位, total:总数, yMinValue:最小值, yMaxValue:最大值, yStepValue:间隔, dataList:[{key:value}] }]}
 */
function getChartOutData(title, data) {
    let dataList = [];
    for (let chartName in data) {
        let { unit, dataInfo } = data[chartName];
        let addData = { title: chartName };
        let max = 0;
        let min = new Date().valueOf();
        let total = 0;
        let thisUnitStats = {};
        let onceDataList = [];
        for (let i = 0; i < dataInfo.length; i++) {
            let { key, value } = dataInfo[i];
            let { dataNum, dataUnit } = privateTools_1.separateDataAndUint(value);
            min = Math.min(min, dataNum);
            max = Math.max(max, dataNum);
            thisUnitStats[dataUnit] = thisUnitStats[dataUnit] ? thisUnitStats[dataUnit] + 1 : 1;
            total += dataNum;
            onceDataList.push({ key, value: dataNum, unit: dataUnit });
        }
        let statsUnit = privateTools_1.getUnitMaxOccNum(thisUnitStats);
        let thisChartUnit = unit || statsUnit || "";
        addData["unit"] = thisChartUnit;
        addData["total"] = total;
        let { maxNumber, minNumber, stepNumber } = privateTools_1.unifiedMaxAndMinValueAndStep(max, min);
        addData["yMinValue"] = minNumber;
        addData["yMaxValue"] = maxNumber;
        addData["yStepValue"] = stepNumber;
        addData["dataList"] = onceDataList;
        dataList.push(addData);
    }
    return { title, dataList };
}
exports.getChartOutData = getChartOutData;
/**
 * getListOutData  获取列表返回结果
 * @param title 数据标题
 * @param data 数据体  格式：[{key:"key1", values:[data1value1, data2value1, data3value1] }, {key:"key2", values:[data1value2, data2value2, data3value2] }]
 * @returns {title:数据标题, total:数据总条数, titleList:[表头...], valueList:[[数据列表...],[数据列表...]]}
 */
function getListOutData(title, data) {
    let titleList = [];
    let valueList = [];
    let maxLength = 0;
    data.forEach(onceData => {
        let { key, values } = onceData;
        titleList.push(key);
        for (let i = 0; i < values.length; i++) {
            let value = values[i] || "";
            valueList[i] ? valueList[i].push(value) : valueList[i] = [value];
            Math.max(maxLength, i + 1);
        }
    });
    return { title, total: 0, titleList, valueList };
}
exports.getListOutData = getListOutData;
/**
 * getKeyValueNumberOutData  获取值为数值的键值返回结果
 * @param title 数据标题
 * @param data 数据体 格式:{key:value, key:value}
 * @returns { title:数据标题, dataList:[{key:"数据key", "value":"数据value", unit:"数据单位"}], total:数据值总数, count:数据总条数 }
 */
function getKeyValueNumberOutData(title, data) {
    let dataList = [];
    let total = 0;
    let count = 0;
    for (let key in data) {
        let { dataNum, dataUnit } = privateTools_1.separateDataAndUint(data[key]);
        total += dataNum;
        count += 1;
        let addData = { key, value: dataNum, unit: dataUnit };
        dataList.push(addData);
    }
    return { title, dataList, total, count };
}
exports.getKeyValueNumberOutData = getKeyValueNumberOutData;
/**
 * getKeyValueNotNumberOutData  获取值为非数值的键值返回结果
 * @param title 数据标题
 * @param data 数据体 格式:{key:value, key:value}
 * @returns { title:数据标题, dataList:[{key:"数据key", "value":"数据value"}], count:数据总条数 }
 */
function getKeyValueNotNumberOutData(title, data) {
    let dataList = [];
    let count = 0;
    for (let key in data) {
        let addData = { key, value: data[key] };
        dataList.push(addData);
        count += 1;
    }
    return { title, dataList, count };
}
exports.getKeyValueNotNumberOutData = getKeyValueNotNumberOutData;
/**
 * getScatterFigureOutData  获取撒点图的返回结果
 * @param title 标题
 * @param data 数据 格式 [{x, y, name}, {x, y, name}, {x, y, name}, {x, y, name}]
 * @returns { title:标题, xMax:x轴最大值, xMin:x最小值, yMax:y最大值, yMin:y最小值, dataList:[{name:点的名称, value:[x坐标, y坐标]} ] };
 */
function getScatterFigureOutData(title, data) {
    let dataList = [];
    let xMaxNumber = 0;
    let xMinNumber = new Date().valueOf();
    let yMaxNumber = 0;
    let yMinNumber = new Date().valueOf();
    data.forEach(item => {
        let { x, y, name } = item;
        let xCoordinateInfo = privateTools_1.separateDataAndUint(x);
        let yCoordinateInfo = privateTools_1.separateDataAndUint(y);
        const XNumber = xCoordinateInfo.dataNum;
        const YNumber = yCoordinateInfo.dataNum;
        yMaxNumber = Math.max(YNumber, yMaxNumber);
        yMinNumber = Math.min(YNumber, yMinNumber);
        xMaxNumber = Math.max(XNumber, xMaxNumber);
        xMinNumber = Math.min(XNumber, xMinNumber);
        let value = [XNumber, YNumber];
        dataList.push({ value, name: name || "" });
    });
    let xMaxMinInfo = privateTools_1.unifiedMaxAndMinValueAndStep(xMaxNumber, xMinNumber);
    let yMaxMinInfo = privateTools_1.unifiedMaxAndMinValueAndStep(yMaxNumber, yMinNumber);
    return { title, xMax: xMaxMinInfo.maxNumber, xMin: xMaxMinInfo.minNumber, yMax: yMaxMinInfo.maxNumber, yMin: yMaxMinInfo.minNumber, dataList };
}
exports.getScatterFigureOutData = getScatterFigureOutData;
//# sourceMappingURL=out.js.map