"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getQytlzdjs = exports.getYdcs = exports.getQycs = void 0;
const moment = require("moment");
const errorEnum_1 = require("../../config/errorEnum");
const serverConfig_1 = require("../../config/serverConfig");
const bizError_1 = require("../../util/bizError");
const cronJob_1 = require("../cronJob");
//测试分析
//企业测试
async function getQycs() {
    const interfaceName = "企业历史里程及时长统计信息接口";
    // let startTime = moment().format("YYYY-MM") + "-01";
    // let endTime = moment().format('YYYY-MM-DD');
    let data = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.enterpriseTestStatus, {});
    let { enterpriseTestStatusList } = data;
    if (!Array.isArray(enterpriseTestStatusList))
        throw new bizError_1.SysError(errorEnum_1.SYSTEMERRORENUM.未按接口协议返回, interfaceName, "enterpriseTestStatusList 不是数组", enterpriseTestStatusList);
    let 企业测试时长数据 = [];
    let 企业测试时长功能数据 = [];
    let 企业测试里程数据 = [];
    let 企业测试里程功能数据 = [];
    enterpriseTestStatusList.forEach(info => {
        let { enterpriseName, testStatistics } = info;
        // if ( !enterpriseName || !testStatistics ) 
        企业测试时长数据.push({ key: enterpriseName, value: testStatistics.duration });
        企业测试时长功能数据.push({ key: enterpriseName, value: testStatistics.autoDuration });
        企业测试里程数据.push({ key: enterpriseName, value: testStatistics.mileage });
        企业测试里程功能数据.push({ key: enterpriseName, value: testStatistics.autoMileage });
    });
    return { 企业测试时长数据, 企业测试时长功能数据, 企业测试里程数据, 企业测试里程功能数据 };
}
exports.getQycs = getQycs;
//月度测试
async function getYdcs() {
    const interfaceName = "月度历史里程及时长统计信息接口";
    let 月度测试时长数据 = [];
    let 月度测试时长功能数据 = [];
    let 月度测试里程数据 = [];
    let 月度测试里程功能数据 = [];
    // let startTime = moment().subtract(1, 'months').format("YYYY-M");
    // let endTime = moment().format("YYYY-M");
    let 月度历史里程及时长 = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.monthlyTestStatus, {});
    let { monthlyTestStatusList } = 月度历史里程及时长;
    if (!Array.isArray(monthlyTestStatusList))
        throw new bizError_1.SysError(errorEnum_1.SYSTEMERRORENUM.未按接口协议返回, interfaceName, "monthlyTestStatusList 不是数组", monthlyTestStatusList);
    let nowTime = new Date(moment().format('YYYY-MM')).valueOf();
    monthlyTestStatusList.forEach(info => {
        let { date, testStatistics } = info;
        let timeMs = new Date(moment(date).add(20, 'months').format('YYYY-MM')).valueOf();
        if (timeMs < nowTime)
            return;
        月度测试时长数据.push({ key: date, value: testStatistics.duration });
        月度测试时长功能数据.push({ key: date, value: testStatistics.autoDuration });
        月度测试里程数据.push({ key: date, value: testStatistics.mileage });
        月度测试里程功能数据.push({ key: date, value: testStatistics.autoMileage });
    });
    return { 月度测试时长数据, 月度测试时长功能数据, 月度测试里程数据, 月度测试里程功能数据 };
}
exports.getYdcs = getYdcs;
//企业脱离自动驾驶比率
async function getQytlzdjs() {
    // "企业历史脱离率统计接口"; 
    let startTime = moment().format("YYYY-MM") + "-01";
    let endTime = moment().format('YYYY-MM-DD');
    let data = await cronJob_1.getInterfaceByInterfaceName(serverConfig_1.dataCenterInterfaceConfig.enterpriseExitRate, { startTime, endTime });
    let { enterpriseExitList } = data;
    enterpriseExitList.sort((a, b) => {
        if (!a.ratio) {
            a.ratio = Math.ceil((a.exitCount / a.autoMileage) * 100 / 100);
            if (a.exitCount == 0 || a.autoMileage == 0) {
                a.ratio = 0;
            }
        }
        if (!b.ratio) {
            b.ratio = Math.ceil((b.exitCount / b.autoMileage) * 100 / 100);
            if (b.exitCount == 0 || b.autoMileage == 0) {
                b.ratio = 0;
            }
        }
        let aRatio = a.ratio;
        let bRatio = b.ratio;
        return bRatio - aRatio;
    });
    let 企业名称data = [];
    let 次数data = [];
    let 比率data = [];
    let enterpriseExitListTop10 = enterpriseExitList.slice(0, 10);
    enterpriseExitListTop10.forEach(info => {
        let { autoMileage, enterpriseName, exitCount, ratio } = info;
        企业名称data.push(enterpriseName);
        次数data.push(ratio + "次/公里");
        比率data.push(ratio + "%");
    });
    let 企业测试自动驾驶比率 = [
        { key: "企业名称", values: 企业名称data },
        { key: "次/公里", values: 次数data },
        { key: "比率", values: 比率data },
    ];
    return 企业测试自动驾驶比率;
}
exports.getQytlzdjs = getQytlzdjs;
//# sourceMappingURL=csfxData.js.map