"use strict";
/**
 * 孵化器信息表
 * operationName不可修改 2023-02-06 确定此需求
 * uscc不可修改 2023-02-06 确定此需求
 * 首次登录要求改密码 不改密码不能继续操作 2023-02-07 确定此需求
 * 管理后台列表页面一页展示10条 2023-02-08 确定此需求
 * 孵化器账号不能被删除 只能被禁用 2023-02-08 确定此需求
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFuHuaQiToList = exports.createFuHuaQiUser = exports.findAllFuHuaQi = exports.findFuHuaQiUserCount = exports.findFuHuaQiUserList = exports.groupFindFuHuaQi = exports.findAllFuHuaQiOperationUsccMap = exports.findAllFuHuaQiOperationNameMap = exports.findFuHuaQiCount = exports.findFuHuaQiList = exports.findFuHuaQiListByPage = exports.findFuHuaQiByToken = exports.findFuHuaQiByUscc = exports.findFuHuaQiByName = exports.findFuHuaQiByUSCC = exports.save = exports.initModel = void 0;
const mongoose_1 = require("mongoose");
const dbInit_1 = require("../../db/mongo/dbInit");
const hatchingGroundSchema = new mongoose_1.Schema({
    personInChargeAdd: String,
    siteAcreage: Number,
    leasePrice: Number, //孵化场地出租单价
});
const fuHuaQiSchema = new mongoose_1.Schema({
    name: { type: String, index: true },
    operationName: String,
    uscc: { type: String, index: true },
    virtualEnterpriseNum: { type: Number, default: 0 },
    logonTime: Number,
    incubatedAcreage: Number,
    acreageTotal: Number,
    acreagePersonalUse: Number,
    lv: Number,
    identificationTime: Number,
    industry: [Number],
    institutionalNature: Number,
    liaison: String,
    liaisonPhone: String,
    personInCharge: String,
    personInChargePhone: String,
    hatchingGround: { type: [hatchingGroundSchema], default: [] },
    /**登录相关 */
    pwd: String,
    token: { type: String, index: true },
    tokenMs: Number,
    firstLoginIsChangePwd: { type: Boolean, default: false },
    createTime: Number,
    userState: { type: Boolean, default: false } //是否禁用
});
var fuHuaQiModel;
function initModel() {
    fuHuaQiModel = dbInit_1.baseDB.model('fuhuaqi', fuHuaQiSchema);
    fuHuaQiModel.selectOnceData = async function (paramater) {
        let selectInfo = await fuHuaQiModel.findOne(paramater).exec();
        if (selectInfo) {
            if (!selectInfo.runSave) {
                selectInfo.runSave = selectInfo.save;
                selectInfo.save = save.bind(selectInfo);
            }
        }
        return selectInfo;
    };
}
exports.initModel = initModel;
async function save(throwError = false) {
    if (!this.isModified())
        return;
    await this.runSave({ validateBeforeSave: false }).catch(err => {
        console.log(err);
    });
}
exports.save = save;
/**
 * 通过统一信用代码获取孵化器信息
 * 支持.save方法保存对象修改
 * @param uscc 孵化器统一信用代码
 * @returns {}
 */
async function findFuHuaQiByUSCC(uscc) {
    return await fuHuaQiModel.selectOnceData({ uscc });
}
exports.findFuHuaQiByUSCC = findFuHuaQiByUSCC;
/**
 * 通过孵化器名称获取孵化器信息
 * @param name 孵化器名称
 * @returns {}
 */
async function findFuHuaQiByName(name) {
    return await fuHuaQiModel.findOne({ name });
}
exports.findFuHuaQiByName = findFuHuaQiByName;
/**
 * 通过信用代码获取孵化器信息
 * @param uscc 信用代码
 * @returns 信用代码为uscc的孵化器信息
 */
async function findFuHuaQiByUscc(uscc) {
    return await fuHuaQiModel.findOne({ uscc });
}
exports.findFuHuaQiByUscc = findFuHuaQiByUscc;
/**
 * 通过token获取孵化器信息   弃用
 * 中间件使用
 * @param token token
 * @returns 孵化器信息
 */
async function findFuHuaQiByToken(token) {
    return await fuHuaQiModel.findOne({ token }).exec();
}
exports.findFuHuaQiByToken = findFuHuaQiByToken;
/**
 * 分页获取符合条件的孵化器列表
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findFuHuaQiListByPage(selectParam, skipCount) {
    return await fuHuaQiModel.find(selectParam).skip(skipCount).limit(10);
}
exports.findFuHuaQiListByPage = findFuHuaQiListByPage;
/**
 * 获取符合条件的所有孵化器列表
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findFuHuaQiList(selectParam) {
    return await fuHuaQiModel.find(selectParam);
}
exports.findFuHuaQiList = findFuHuaQiList;
/**
 * 获取所有孵化器数量
 * @param selectParam 查询参数
 * @returns number 数据数量
 */
async function findFuHuaQiCount(selectParam) {
    return await fuHuaQiModel.find(selectParam).count();
}
exports.findFuHuaQiCount = findFuHuaQiCount;
/**
 * 获取所有运营机构名称的map
 * @returns map key:统一信用代码 value:运营机构名称
 */
async function findAllFuHuaQiOperationNameMap() {
    let dataList = await fuHuaQiModel.find({});
    let map = {};
    dataList.forEach(info => {
        map[info.uscc] = info.operationName;
    });
    return map;
}
exports.findAllFuHuaQiOperationNameMap = findAllFuHuaQiOperationNameMap;
/**
 * 获取所有运营机构的map
 * @returns map key:运营机构名称 value:uscc
 */
async function findAllFuHuaQiOperationUsccMap() {
    let dataList = await fuHuaQiModel.find({});
    let map = {};
    dataList.forEach(info => {
        map[info.operationName] = info.uscc;
    });
    return map;
}
exports.findAllFuHuaQiOperationUsccMap = findAllFuHuaQiOperationUsccMap;
/**
 * 聚合查询 孵化器所拥有的企业数量
 * @returns {} key=孵化器统一信用 value=企业数量
 */
async function groupFindFuHuaQi() {
    let match = { draftLock: true }; //前置条件
    let dataList = await fuHuaQiModel.aggregate([{ $match: match }, { $group: { _id: "$fuHuaQiUscc", count: { $sum: 1 } } }]).exec();
    let result = {};
    dataList.forEach(info => {
        let { _id, count } = info;
        result[_id] = count;
    });
    return result;
}
exports.groupFindFuHuaQi = groupFindFuHuaQi;
/**
 * 获取所有孵化器
 * @param selectParam 查询参数
 * @param skipCount 跳过数量
 * @returns [] 孵化器列表
 */
async function findFuHuaQiUserList(selectParam, skipCount) {
    return await fuHuaQiModel.find(selectParam).skip(skipCount).limit(10);
}
exports.findFuHuaQiUserList = findFuHuaQiUserList;
/**
 * 获取所有孵化器
 * @param selectParam 查询参数
 * @returns number 数据数量
 */
async function findFuHuaQiUserCount(selectParam) {
    return await fuHuaQiModel.find(selectParam).count();
}
exports.findFuHuaQiUserCount = findFuHuaQiUserCount;
async function findAllFuHuaQi() {
    return await fuHuaQiModel.find({ userState: false });
}
exports.findAllFuHuaQi = findAllFuHuaQi;
/**
 * 添加孵化器账号
 * @param param 新增参数
 * @returns
 */
async function createFuHuaQiUser(param) {
    return await fuHuaQiModel.create(param);
}
exports.createFuHuaQiUser = createFuHuaQiUser;
async function createFuHuaQiToList(fuHuaQiList) {
    await fuHuaQiModel.insertMany(fuHuaQiList);
}
exports.createFuHuaQiToList = createFuHuaQiToList;
//# sourceMappingURL=fuhuaqi.js.map