"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postForm = exports.post = exports.get = void 0;
const request = require("request");
const bizError_1 = require("./bizError");
function get(url, query, headers) {
    if (!url || (url.search(/http:/) && url.search(/https:/)))
        throw new bizError_1.BizError(!url ? "请求地址为空" : "请求地址错误");
    return new Promise((resolve, reject) => {
        let paramater = { url, json: true };
        if (query)
            paramater.qs = query;
        if (headers)
            paramater.headers = headers;
        request.get(paramater, function (err, r, body) {
            if (err)
                return reject(err);
            if (r && r.statusCode != 200)
                return reject(new Error('httpError:' + r.statusCode));
            resolve(body);
        });
    });
}
exports.get = get;
function post(url, body, headers) {
    if (!url || (url.search(/http:/) && url.search(/https:/)))
        throw new bizError_1.BizError(!url ? "请求地址为空" : "请求地址错误");
    let header = { "content-type": "application/json" };
    return new Promise((resolve, reject) => {
        request({
            url: url,
            method: "POST",
            json: true,
            headers: Object.assign(header, headers),
            body: body
        }, function (error, response, body) {
            if (!error && response.statusCode == 200) {
                resolve(body);
            }
            else {
                reject(error);
            }
        });
    });
}
exports.post = post;
function postForm(url, body, headers) {
    if (!url || (url.search(/http:/) && url.search(/https:/)))
        throw new bizError_1.BizError(!url ? "请求地址为空" : "请求地址错误");
    return new Promise((resolve, reject) => {
        request({
            url: url,
            method: "POST",
            json: true,
            form: body
        }, function (error, response, res) {
            if (!error) {
                resolve(res);
            }
            else {
                reject(error);
            }
        });
    });
}
exports.postForm = postForm;
//# sourceMappingURL=request.js.map